@@ -1,3 +1,4 @@
+
 class Universes:
     """A class to access the Universes PDI API endpoint."""
 
@@ -20,3 +21,16 @@ class Universes:
         """
 
         return self._request(self.url_universes, limit=limit)
+
+    def get_universe(self, id: str):
+        """
+        Get a Universe by id.
+
+        `Args:`
+            id: str
+                The Universe id
+        `Returns:`
+            parsons.Table
+                A Parsons table of all the data.
+        """
+        return self._request(f"{self.url_universes}/{id}")
